==> ugene_1.3.3+repack.orig.tar.gz: ugene-1.3.3/src/core/src/selection/AnnotationSelection.h <==
/*****************************************************************
* Unipro UGENE - Integrated Bioinformatics Suite
* Copyright (C) 2008 Unipro, Russia (http://ugene.unipro.ru)
* All Rights Reserved
* 
*     This source code is distributed under the terms of the
*     GNU General Public License. See the files COPYING and LICENSE
*     for details.
*****************************************************************/

#ifndef _GB2_ANNOTATION_SELECTION_H_
#define _GB2_ANNOTATION_SELECTION_H_

#include "SelectionTypes.h"

namespace GB2 {

class Annotation;
class AnnotationGroup;
class AnnotationTableObject;
class DNATranslation;

class GB2_COREAPI_EXPORT AnnotationSelectionData {
public:
	AnnotationSelectionData(Annotation* a, int lIdx) : annotation(a), locationIdx(lIdx){}
	// the annotation selected
	Annotation* annotation;

	//location idx that is preferable for visualization
	// -1 == not specified, 0..N == idx of LRegion in 'location' field
	//BUG:404: do we need a separate class for this feature?
	int			locationIdx; 

	bool operator==(const AnnotationSelectionData& d) const {return d.annotation == annotation && d.locationIdx == locationIdx;}

    int getSelectedRegionsLen() const;
};

class  GB2_COREAPI_EXPORT AnnotationSelection : public GSelection {
	Q_OBJECT
public:
	AnnotationSelection(QObject* p = NULL) : GSelection(GSelectionTypes::ANNOTATIONS, p) {}

	const QList<AnnotationSelectionData>& getSelection() const {return selection;}

	const AnnotationSelectionData* getAnnotationData(const Annotation*) const;

	// adds annotation to selection. 
	// if annotation is already in selection and have a different locationIdx -> removes the old annotaiton selection data
	// and adds the annotation again with updated locationIdx
	void addToSelection(Annotation* a, int locationIdx = -1);
	
	void removeFromSelection(Annotation* a);

	virtual bool isEmpty() const {return selection.isEmpty();}

	virtual void clear();

	virtual void removeObjectAnnotations(AnnotationTableObject* obj);

	bool contains(const Annotation* a) const {return getAnnotationData(a)!=NULL;}

    static void getAnnotationSequence(QByteArray& res, const AnnotationSelectionData& sd, char gapSym, 
                                      const QByteArray& seq, DNATranslation* complTT, DNATranslation* aminoTT);

signals:
	void si_selectionChanged(
		AnnotationSelection* thiz, 
		const QList<Annotation*>& added, 
		const QList<Annotation*>& removed);

private:
	QList<AnnotationSelectionData> selection;
};



//////////////////////////////////////////////////////////////////////////
// AnnotationGroupSelection

class  GB2_COREAPI_EXPORT AnnotationGroupSelection : public GSelection {
    Q_OBJECT
public:
    AnnotationGroupSelection(QObject* p = NULL) : GSelection(GSelectionTypes::ANNOTATION_GROUPS, p) {}

    const QList<AnnotationGroup*>& getSelection() const {return selection;}

    void addToSelection(AnnotationGroup* g);

    void removeFromSelection(AnnotationGroup* g);

    virtual bool isEmpty() const {return selection.isEmpty();}

    virtual void clear();

    virtual void removeObjectGroups(AnnotationTableObject* obj);

    bool contains(AnnotationGroup* g) const {return selection.contains(g);}

signals:
    void si_selectionChanged(
        AnnotationGroupSelection* thiz, 
        const QList<AnnotationGroup*>& added, 
        const QList<AnnotationGroup*>& removed);

private:
    QList<AnnotationGroup*> selection;
};


}//namespace

#endif

==> ugene_1.5.2+repack.orig.tar.gz: ugene-1.5.2/src/core/src/selection/AnnotationSelection.h <==
/*****************************************************************
* Unipro UGENE - Integrated Bioinformatics Suite
* Copyright (C) 2008,2009 Unipro, Russia (http://ugene.unipro.ru)
* All Rights Reserved
* 
*     This source code is distributed under the terms of the
*     GNU General Public License. See the files COPYING and LICENSE
*     for details.
*****************************************************************/

#ifndef _GB2_ANNOTATION_SELECTION_H_
#define _GB2_ANNOTATION_SELECTION_H_

#include "SelectionTypes.h"
#include <core_api/LRegion.h>

namespace GB2 {

class Annotation;
class AnnotationGroup;
class AnnotationTableObject;
class DNATranslation;

class GB2_COREAPI_EXPORT AnnotationSelectionData {
public:
	AnnotationSelectionData(Annotation* a, int lIdx) : annotation(a), locationIdx(lIdx){}
	// the annotation selected
	Annotation* annotation;

	//location idx that is preferable for visualization
	// -1 == not specified, 0..N == idx of LRegion in 'location' field
	//BUG:404: do we need a separate class for this feature?
	int			locationIdx; 

	bool operator==(const AnnotationSelectionData& d) const {return d.annotation == annotation && d.locationIdx == locationIdx;}

    int getSelectedRegionsLen() const;
    
    QList<LRegion> getSelectedRegions() const;
};

class  GB2_COREAPI_EXPORT AnnotationSelection : public GSelection {
	Q_OBJECT
public:
	AnnotationSelection(QObject* p = NULL) : GSelection(GSelectionTypes::ANNOTATIONS, p) {}

	const QList<AnnotationSelectionData>& getSelection() const {return selection;}

	const AnnotationSelectionData* getAnnotationData(const Annotation*) const;

	// adds annotation to selection. 
	// if annotation is already in selection and have a different locationIdx -> removes the old annotaiton selection data
	// and adds the annotation again with updated locationIdx
	void addToSelection(Annotation* a, int locationIdx = -1);
	
	void removeFromSelection(Annotation* a, int locationIdx = -1);

	virtual bool isEmpty() const {return selection.isEmpty();}

	virtual void clear();

	virtual void removeObjectAnnotations(AnnotationTableObject* obj);

	bool contains(const Annotation* a) const {return getAnnotationData(a)!=NULL;}
    
    bool contains(const Annotation* a, int locationIdx) const;

    static void getAnnotationSequence(QByteArray& res, const AnnotationSelectionData& sd, char gapSym, 
                                      const QByteArray& seq, DNATranslation* complTT, DNATranslation* aminoTT);

signals:
	void si_selectionChanged(
		AnnotationSelection* thiz, 
		const QList<Annotation*>& added, 
		const QList<Annotation*>& removed);

private:
	QList<AnnotationSelectionData> selection;
};



//////////////////////////////////////////////////////////////////////////
// AnnotationGroupSelection

class  GB2_COREAPI_EXPORT AnnotationGroupSelection : public GSelection {
    Q_OBJECT
public:
    AnnotationGroupSelection(QObject* p = NULL) : GSelection(GSelectionTypes::ANNOTATION_GROUPS, p) {}

    const QList<AnnotationGroup*>& getSelection() const {return selection;}

    void addToSelection(AnnotationGroup* g);

    void removeFromSelection(AnnotationGroup* g);

    virtual bool isEmpty() const {return selection.isEmpty();}

    virtual void clear();

    virtual void removeObjectGroups(AnnotationTableObject* obj);

    bool contains(AnnotationGroup* g) const {return selection.contains(g);}

signals:
    void si_selectionChanged(
        AnnotationGroupSelection* thiz, 
        const QList<AnnotationGroup*>& added, 
        const QList<AnnotationGroup*>& removed);

private:
    QList<AnnotationGroup*> selection;
};


}//namespace

#endif
